@@ -52,7 +52,7 @@ bssmle <- function(formula, data, alpha, k = 1) {
   t <- c(Tv, Tu[delta > 0])
   nk <- floor(k * length(t)^(1/3))
   max <- nk + 1
-  knots <- quantile(t, seq(0, 1, by = 1 / (nk + 1)))[2:max]
+  knots <- unique(quantile(t[t < max(t) & t > min(t)], seq(0, 1, by = 1 / (nk + 1)))[2:max])
   Bv <- bs(Tv, knots = knots, degree = 3, intercept = TRUE, Boundary.knots = c(min(t), max(t)))
   Tu[delta == 0] <- max(t)
   Bu <- predict(Bv, Tu)
@@ -289,11 +289,86 @@ bssmle <- function(formula, data, alpha, k = 1) {
     unname(ui)
   }
 
+  heq_g0 <- function(x) {
+    b1 <- x[(2 * n + 1):(2 * n + q)]
+    b2 <- x[(2 * n + q + 1):(2 * n + 2 * q)]
+
+    ## Monotonicity constraints
+    ui <- rep(0, 2 * (n - 1))
+
+    ## evaluate cif at the last constrol point of B spline
+    cif1 <- function(xi, eta){
+      if(a1 > 0){
+        (1 + a1 * exp(xi + eta))^(-1 / a1)
+      } else if(a1 == 0){
+        exp(-exp(xi + eta))
+      }
+    }
+    cif2 <- function(xi, eta){
+      if(a2 > 0){
+        (1 + a2 * exp(xi + eta))^(-1 / a2)
+      } else if(a2 == 0){
+        exp(-exp(xi + eta))
+      }
+    }
+
+    ##Boundedness constraints
+    for(i in 1:dim(comb)[1]){
+      eta1 <- b1 %*% t(comb[i,])
+      eta2 <- b2 %*% t(comb[i,])
+      minmax <- (cif1(xi = x[1], eta = eta1) + cif2(xi = x[(n + 1)], eta = eta2)) - 2
+      ui <- c(ui, minmax)
+    }
+    unname(ui)
+  }
+
+  heq_jac_g0 <- function(x) {
+    b1 <- x[(2 * n + 1):(2 * n + q)]
+    b2 <- x[(2 * n + q + 1):(2 * n + 2 * q)]
+    nBS <- 2 * n
+
+    ## Monotonicity constraints
+    ui <- matrix(rep(0, times = (nBS * (nBS - 2))), ncol = nBS, nrow = (nBS - 2), byrow = TRUE)
+
+    zero <- matrix(rep(0, times = (dim(ui)[1] * (2 * q))), ncol = (2 * q))
+    ui <- cbind(ui, zero)
+
+    ## Boundedness constraints for the last control point
+    line <- c(rep(0, times = n),
+              rep(0, times = n))
+
+    dcif1 <- function(xi, eta){
+      if(a1 > 0){
+        (1 + a1 * exp(xi + eta))^(-(1 / a1) - 1) * exp(xi + eta)
+      } else if(a1 == 0){
+        exp(-exp(xi + eta)) * exp(xi + eta)
+      }
+    }
+    dcif2 <- function(xi, eta){
+      if(a2 > 0){
+        (1 + a2 * exp(xi + eta))^(-(1 / a2) - 1) * exp(xi + eta)
+      } else if(a2 == 0){
+        exp(-exp(xi + eta)) * exp(xi + eta)
+      }
+    }
+
+    for(i in 1:dim(comb)[1]){
+      line_i <- c(line, unlist(comb[i,]), unlist(comb[i,]))
+      eta1 <- b1 %*% t(comb[i,])
+      eta2 <- b2 %*% t(comb[i,])
+      minmax <- line_i * (as.vector(dcif1(xi = x[1], eta = eta1)) + as.vector(dcif2(xi = x[(n + 1)], eta = eta2)))
+      ui <- rbind(ui, minmax)
+    }
+    unname(ui)
+  }
+
   est <- try(alabama::constrOptim.nl(par = b0,
                                      fn = nLL,
                                      gr = Grad,
                                      hin = eval_g0,
                                      hin.jac = eval_jac_g0,
+                                     heq = heq_g0,
+                                     heq.jac = heq_jac_g0,
                                      control.optim = list(maxit = 2000),
                                      control.outer = list(trace = FALSE)), silent = TRUE)
 
