@@ -11,17 +11,17 @@
 #' \item{vcov.event1}{the estimated bootstrap variance-covariance matrix for cause-specific Wald test (event type 1)}
 #' \item{vcov.event2}{the estimated bootstrap variance-covariance matrix for cause-specific Wald test (event type 2)}
 #' \item{table}{a table including test statistic, degrees of freedom, and p-value}
-#' @seealso The fitted semiparametric regression on cumulative incidence function with interval-censored competing risks data \code{\link[intccr]{ciregic}}
+#' @seealso The fitted semiparametric regression on cumulative incidence function with interval-censored competing risks data \code{\link[intccr]{ciregic}} and left-truncated and interval-censored competing risks data \code{\link[intccr]{ciregic_lt}}
 #' @examples
 #' ## Continuing the ciregic(...) example
+#' library(intccr)
 #' waldtest(obj1 = fit)
 #' set.seed(12345)
 #' newdata <- dataprep(data = longdata, ID = id, time = t,
 #'                     event = c, Z = c(z1, z2))
 #' fit.nested <- ciregic(formula = Surv2(v = v, u = u, event = c) ~ z2, data = newdata,
-#'                alpha = c(1, 1), nboot = 0, do.par = FALSE)
+#'                       alpha = c(1, 1), nboot = 0, do.par = FALSE)
 #' waldtest(obj1 = fit, obj2 = fit.nested)
-#'
 #' @export
 
 waldtest <- function(obj1, obj2 = NULL, ...) {
@@ -68,7 +68,7 @@ waldtest <- function(obj1, obj2 = NULL, ...) {
 
   diff.coef <- coef.full - coef.nested
 
-  if((class(try(solve(vcov), silent = TRUE)) != "matrix")) {
+  if(sum(class(try(solve(vcov), silent = TRUE)) == "try-error") != 0) {
     stop("Variance-covariance matrix is sigular.")
   }
   stat <- pval <- rep(NA, 3)
